==> vokoscreen_2.4.0.orig.tar.gz: vokoscreen-2.4.0/language/vokoscreen_ast.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="ast" version="2.0">
<context>
    <name>AlsaBusyDialog</name>
    <message>
        <source>Device is busy</source>
        <translation>El preséu ta ocupáu</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Desconocíu</translation>
    </message>
    <message>
        <source>Device</source>
        <translation>Preséu</translation>
    </message>
    <message>
        <source>Used by</source>
        <translation>Usáu por</translation>
    </message>
</context>
<context>
    <name>MailDialog</name>
    <message>
        <source>Mail last Video</source>
        <translation>Dunviar per corréu&apos;l vidéu caberu</translation>
    </message>
    <message>
        <source>Mail one or more selected Video</source>
        <translation>Dunviar per corréu ún o más videos esbillaos</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Dunviar</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Encaboxar</translation>
    </message>
</context>
<context>
    <name>NoPlayerDialog</name>
    <message>
        <source>Please install a videoplayer</source>
        <translation>Por favor, instala un reproductor de videu</translation>
    </message>
</context>
<context>
    <name>QvkMail</name>
    <message>
        <source>You find the Video as attachment</source>
        <translation>Pues alcontrar el vidéu como axuntu</translation>
    </message>
    <message>
        <source>Select one or more files</source>
        <translation>Esbilla unu o más ficheros</translation>
    </message>
</context>
<context>
    <name>QvkWebcamWindow</name>
    <message>
        <source>Border</source>
        <translation>Bervesu</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Zarrar</translation>
    </message>
    <message>
        <source>Show over fullscreen</source>
        <translation>Amosar sobro pantalla completa</translation>
    </message>
    <message>
        <source>Right click for menu</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>User-defined</source>
        <translation>Definíu pol usuariu</translation>
    </message>
</context>
<context>
    <name>WebcamBusyDialog</name>
    <message>
        <source>Device is busy</source>
        <translation>El preséu ta ocupáu</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <source>Device</source>
        <translation>Preséu</translation>
    </message>
    <message>
        <source>Used by</source>
        <translation>Usáu por</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Desconocíu</translation>
    </message>
</context>
<context>
    <name>regionselection</name>
    <message>
        <source>doubleclick extended to the edge</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>screencast</name>
    <message>
        <source>Fullscreen</source>
        <translation>Pantalla completa</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>Ventana</translation>
    </message>
    <message>
        <source>Area</source>
        <translation>Fastera</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Lente</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Audiu</translation>
    </message>
    <message>
        <source>Alsa</source>
        <translation>ALSA</translation>
    </message>
    <message>
        <source>Pulse</source>
        <translation>Pulse</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Por defeutu</translation>
    </message>
    <message>
        <source>Codec</source>
        <translation>Codec</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>Nun grabar el mur</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>Camín del vidéu</translation>
    </message>
    <message>
        <source>Player</source>
        <translation>Reproductor</translation>
    </message>
    <message>
        <source>Vokoscreen minimized when recording starts</source>
        <translation>Vokoscreen minimizáu cuando la grabación entame</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Entamar</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Aparar</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Posar</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Reproducir</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Dunviar</translation>
    </message>
    <message>
        <source>Recording time</source>
        <translation>Tiempu de grabación</translation>
    </message>
    <message>
        <source>Size in KB</source>
        <translation>Grandor en KB</translation>
    </message>
    <message>
        <source>Recording screensize</source>
        <translation>Grandor de pantalla al grabar</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Formatu</translation>
    </message>
    <message>
        <source>Settings fps</source>
        <translation>Axustar FPS</translation>
    </message>
    <message>
        <source>Open Directory</source>
        <translation>Abrir direutoriu</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>Cuenta atrás</translation>
    </message>
    <message>
        <source>Play last Video</source>
        <translation>Reproducir el vidéu caberu</translation>
    </message>
    <message>
        <source>Send Video</source>
        <translation>Dunviar vidéu</translation>
    </message>
    <message>
        <source>Select one or more devices</source>
        <translation>Esbilla ún o más preseos</translation>
    </message>
    <message>
        <source>Actual frames per second</source>
        <translation>Cuadros per segundu d&apos;anguaño</translation>
    </message>
    <message>
        <source>Go</source>
        <translation>DIr</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>Páxina d&apos;aniciu</translation>
    </message>
    <message>
        <source>Support</source>
        <translation>Sofitu</translation>
    </message>
    <message>
        <source>Developer</source>
        <translation>Desendolcador</translation>
    </message>
    <message>
        <source>Frames</source>
        <translation>Frames</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Donar</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>Tornes</translation>
    </message>
    <message>
        <source>Sourcecode</source>
        <translation>Códigu fonte</translation>
    </message>
    <message>
        <source>Show in systray</source>
        <translation>Amosar na bandexa&apos;l sistema</translation>
    </message>
    <message>
        <source>New version available</source>
        <translation>Versión nueva disponible</translation>
    </message>
    <message>
        <source>Videocodec</source>
        <translation>Codec vidéu</translation>
    </message>
    <message>
        <source>Audiocodec</source>
        <translation>Codec soníu</translation>
    </message>
    <message>
        <source>Webcam</source>
        <translation>Cámara web</translation>
    </message>
    <message>
        <source>Select webcam</source>
        <translation>Esbillar cámara web</translation>
    </message>
    <message>
        <source>Mirrored</source>
        <translation>Espeyáu</translation>
    </message>
    <message>
        <source>Display</source>
        <translation>Pantalla</translation>
    </message>
    <message>
        <source>All Displays</source>
        <translation>Toles pantalles</translation>
    </message>
    <message>
        <source>Developer Homepage</source>
        <translation>Páxina web del desendolcador</translation>
    </message>
    <message>
        <source>Recorder</source>
        <translation>Grabador</translation>
    </message>
    <message>
        <source>Select recorder</source>
        <translation>Esbilar grabador</translation>
    </message>
</context>
</TS>

==> vokoscreen_2.5.0.orig.tar.gz: vokoscreen-2.5.0/language/vokoscreen_ast.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="ast" version="2.0">
<context>
    <name>AlsaBusyDialog</name>
    <message>
        <source>Device is busy</source>
        <translation>El preséu ta ocupáu</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Desconocíu</translation>
    </message>
    <message>
        <source>Device</source>
        <translation>Preséu</translation>
    </message>
    <message>
        <source>Used by</source>
        <translation>Usáu por</translation>
    </message>
</context>
<context>
    <name>Dialog</name>
    <message>
        <source>Show Click Settings</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MailDialog</name>
    <message>
        <source>Mail last Video</source>
        <translation>Dunviar per corréu&apos;l vidéu caberu</translation>
    </message>
    <message>
        <source>Mail one or more selected Video</source>
        <translation>Dunviar per corréu ún o más videos esbillaos</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Dunviar</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Encaboxar</translation>
    </message>
</context>
<context>
    <name>NoPlayerDialog</name>
    <message>
        <source>Please install a videoplayer</source>
        <translation>Por favor, instala un reproductor de videu</translation>
    </message>
</context>
<context>
    <name>QvkMail</name>
    <message>
        <source>You find the Video as attachment</source>
        <translation>Alcuentres el vidéu como axuntu</translation>
    </message>
    <message>
        <source>Select one or more files</source>
        <translation>Esbilla unu o más ficheros</translation>
    </message>
</context>
<context>
    <name>QvkRegionChoise</name>
    <message>
        <source>double-click to maximize</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>QvkWebcamWindow</name>
    <message>
        <source>Border</source>
        <translation>Berbesu</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Zarrar</translation>
    </message>
    <message>
        <source>Show over fullscreen</source>
        <translation>Amosar sobro pantalla completa</translation>
    </message>
    <message>
        <source>Right click for menu</source>
        <translation>Clic drechu pal menú</translation>
    </message>
    <message>
        <source>User-defined</source>
        <translation>Definíu pol usuariu</translation>
    </message>
</context>
<context>
    <name>WebcamBusyDialog</name>
    <message>
        <source>Device is busy</source>
        <translation>El preséu ta ocupáu</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <source>Device</source>
        <translation>Preséu</translation>
    </message>
    <message>
        <source>Used by</source>
        <translation>Usáu por</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Desconocíu</translation>
    </message>
</context>
<context>
    <name>regionselection</name>
    <message>
        <source>double-click to maximize</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>screencast</name>
    <message>
        <source>Fullscreen</source>
        <translation>Pantalla completa</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>Ventana</translation>
    </message>
    <message>
        <source>Area</source>
        <translation>Fastera</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Lente</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Audiu</translation>
    </message>
    <message>
        <source>Alsa</source>
        <translation>ALSA</translation>
    </message>
    <message>
        <source>Pulse</source>
        <translation>Pulse</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Por defeutu</translation>
    </message>
    <message>
        <source>Codec</source>
        <translation>Codec</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>Nun grabar el mur</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>Camín del vidéu</translation>
    </message>
    <message>
        <source>Player</source>
        <translation>Reproductor</translation>
    </message>
    <message>
        <source>Vokoscreen minimized when recording starts</source>
        <translation>Vokoscreen minimizáu cuando la grabación entame</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Entamar</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Aparar</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Posar</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Reproducir</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Dunviar</translation>
    </message>
    <message>
        <source>Recording time</source>
        <translation>Tiempu de grabación</translation>
    </message>
    <message>
        <source>Size in KB</source>
        <translation>Grandor en KB</translation>
    </message>
    <message>
        <source>Recording screensize</source>
        <translation>Grandor de pantalla al grabar</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Formatu</translation>
    </message>
    <message>
        <source>Settings fps</source>
        <translation>Axustar FPS</translation>
    </message>
    <message>
        <source>Open Directory</source>
        <translation>Abrir direutoriu</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>Cuenta atrás</translation>
    </message>
    <message>
        <source>Play last Video</source>
        <translation>Reproducir el vidéu caberu</translation>
    </message>
    <message>
        <source>Send Video</source>
        <translation>Dunviar vidéu</translation>
    </message>
    <message>
        <source>Select one or more devices</source>
        <translation>Esbilla ún o más preseos</translation>
    </message>
    <message>
        <source>Actual frames per second</source>
        <translation>Cuadros per segundu d&apos;anguaño</translation>
    </message>
    <message>
        <source>Go</source>
        <translation>DIr</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>Páxina d&apos;aniciu</translation>
    </message>
    <message>
        <source>Support</source>
        <translation>Sofitu</translation>
    </message>
    <message>
        <source>Developer</source>
        <translation>Desendolcador</translation>
    </message>
    <message>
        <source>Frames</source>
        <translation>Frames</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Donar</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>Tornes</translation>
    </message>
    <message>
        <source>Sourcecode</source>
        <translation>Códigu fonte</translation>
    </message>
    <message>
        <source>Show in systray</source>
        <translation>Amosar na bandexa&apos;l sistema</translation>
    </message>
    <message>
        <source>New version available</source>
        <translation>Versión nueva disponible</translation>
    </message>
    <message>
        <source>Videocodec</source>
        <translation>Codec vidéu</translation>
    </message>
    <message>
        <source>Audiocodec</source>
        <translation>Codec soníu</translation>
    </message>
    <message>
        <source>Webcam</source>
        <translation>Cámara web</translation>
    </message>
    <message>
        <source>Select webcam</source>
        <translation>Esbillar cámara web</translation>
    </message>
    <message>
        <source>Mirrored</source>
        <translation>Espeyáu</translation>
    </message>
    <message>
        <source>Display</source>
        <translation>Pantalla</translation>
    </message>
    <message>
        <source>All Displays</source>
        <translation>Toles pantalles</translation>
    </message>
    <message>
        <source>Developer Homepage</source>
        <translation>Páxina web del desendolcador</translation>
    </message>
    <message>
        <source>Recorder</source>
        <translation>Grabador</translation>
    </message>
    <message>
        <source>Select recorder</source>
        <translation>Esbilar grabador</translation>
    </message>
    <message>
        <source>Hide window</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Exit</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Show window</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Lossless</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>
